@@ -76,6 +76,7 @@ gPodderSettings = {
     'ipod_purge_old_episodes': (bool, False),
     'mp3_player_delete_played': (bool, False),
     'disable_pre_sync_conversion': (bool, False),
+    'get_length_from_http_header_if_empty': (bool, False),
     
     # Tray icon and notification settings
     'display_tray_icon': (bool, False),
@@ -106,6 +107,7 @@ gPodderSettings = {
     'use_si_units': ( bool, False ),
     'on_quit_systray': (bool, False),
     'create_m3u_playlists': (bool, False),
+    'reverse_m3u_playlist_order': (bool, False),
     'max_episodes_per_feed': (int, 200),
     'mp3_player_use_scrobbler_log': (bool, False),
     'mp3_player_max_filename_length': (int, 100),
