@@ -344,7 +344,13 @@ class podcastChannel(object):
             f = open(m3u_filename, 'w')
             f.write('#EXTM3U\n')
 
-            for episode in downloaded_episodes:
+            # Check to see if we need to reverse the playlist order
+            if gl.config.reverse_m3u_playlist_order:
+                episodes_m3u = reversed(downloaded_episodes)
+            else:
+                episodes_m3u = downloaded_episodes
+
+            for episode in episodes_m3u:
                 if episode.was_downloaded(and_exists=True):
                     filename = episode.local_filename(create=False)
                     assert filename is not None
@@ -566,7 +572,15 @@ class podcastItem(object):
 
         episode.title = entry.get( 'title', util.get_first_line( util.remove_html_tags( entry.get( 'summary', ''))))
         episode.link = entry.get( 'link', '')
-        episode.description = entry.get( 'summary', entry.get( 'link', entry.get( 'title', '')))
+        episode.description = ''
+
+        # Get the episode description (prefer summary, then subtitle)
+        for key in ('summary', 'subtitle', 'link'):
+            if key in entry:
+                episode.description = entry[key]
+            if episode.description:
+                break
+
         episode.guid = entry.get( 'id', '')
         if entry.get( 'updated_parsed', None):
             episode.pubDate = rfc822.mktime_tz(entry.updated_parsed+(0,))
@@ -605,6 +619,7 @@ class podcastItem(object):
             # This item in the feed has no downloadable enclosure
             return None
 
+        metainfo = None
         if not episode.pubDate:
             metainfo = util.get_episode_info_from_url(episode.url)
             if 'pubdate' in metainfo:
@@ -616,8 +631,21 @@ class podcastItem(object):
         if hasattr(enclosure, 'length'):
             try:
                 episode.length = int(enclosure.length)
-            except:
+                if episode.length == 0:
+                    raise ValueError('Zero-length is not acceptable')
+            except ValueError, ve:
+                log('Invalid episode length: %s (%s)', enclosure.length, ve.message)
                 episode.length = -1
+                # If the configuration option is set, retrieve the length via a HTTP HEAD request
+                if gl.config.get_length_from_http_header_if_empty:
+                    if enclosure.length == '' or episode.length == 0:
+                        if metainfo is None:
+                            metainfo = util.get_episode_info_from_url(episode.url)
+                        if 'length' in metainfo:
+                            try:
+                                episode.length = int(float(metainfo['length']))
+                            except:
+                                log('Cannot convert lenght "%s" in from_feedparser_entry.', str(metainfo['length']), traceback=True)
 
         if hasattr( enclosure, 'type'):
             episode.mimetype = enclosure.type
