@@ -63,7 +63,11 @@ import xml.dom.minidom
 
 
 # Try to detect OS encoding (by Leonid Ponomarev)
-encoding = 'iso-8859-15'
+if gpodder.interface == gpodder.MAEMO:
+    encoding = 'utf8'
+else:
+    encoding = 'iso-8859-15'
+
 if 'LANG' in os.environ and '.' in os.environ['LANG']:
     lang = os.environ['LANG']
     (language, encoding) = lang.rsplit('.', 1)
@@ -151,20 +155,59 @@ def normalize_feed_url(url):
     return None
 
 
-def username_password_from_url( url):
-    """
+def username_password_from_url(url):
+    r"""
     Returns a tuple (username,password) containing authentication
     data from the specified URL or (None,None) if no authentication
     data can be found in the URL.
+
+    See Section 3.1 of RFC 1738 (http://www.ietf.org/rfc/rfc1738.txt)
+
+    >>> username_password_from_url('https://@host.com/')
+    ('', None)
+    >>> username_password_from_url('telnet://host.com/')
+    (None, None)
+    >>> username_password_from_url('ftp://foo:@host.com/')
+    ('foo', '')
+    >>> username_password_from_url('http://a:b@host.com/')
+    ('a', 'b')
+    >>> username_password_from_url(1)
+    Traceback (most recent call last):
+      ...
+    ValueError: URL has to be a string or unicode object.
+    >>> username_password_from_url(None)
+    Traceback (most recent call last):
+      ...
+    ValueError: URL has to be a string or unicode object.
+    >>> username_password_from_url('http://a@b:c@host.com/')
+    Traceback (most recent call last):
+      ...
+    ValueError: "@" must be encoded for username/password (RFC1738).
+    >>> username_password_from_url('ftp://a:b:c@host.com/')
+    Traceback (most recent call last):
+      ...
+    ValueError: ":" must be encoded for username/password (RFC1738).
+    >>> username_password_from_url('http://i%2Fo:P%40ss%3A@host.com/')
+    ('i/o', 'P@ss:')
+    >>> username_password_from_url('ftp://%C3%B6sterreich@host.com/')
+    ('\xc3\xb6sterreich', None)
     """
+    if type(url) not in (str, unicode):
+        raise ValueError('URL has to be a string or unicode object.')
+
     (username, password) = (None, None)
 
-    (scheme, netloc, path, params, query, fragment) = urlparse.urlparse( url)
+    (scheme, netloc, path, params, query, fragment) = urlparse.urlparse(url)
 
     if '@' in netloc:
         (authentication, netloc) = netloc.rsplit('@', 1)
         if ':' in authentication:
             (username, password) = authentication.split(':', 1)
+            # RFC1738 dictates that we should not allow these unquoted
+            # characters in the username and password field (Section 3.1).
+            for c in (':', '@', '/'):
+                if c in username or c in password:
+                    raise ValueError('"%c" must be encoded for username/password (RFC1738).' % c)
             username = urllib.unquote(username)
             password = urllib.unquote(password)
         else:
@@ -304,7 +347,7 @@ def format_date(timestamp):
     try:
         timestamp_date = time.localtime(timestamp)[:3]
     except ValueError, ve:
-        log('Warning: Cannot convert timestamp', sender=self, traceback=True)
+        log('Warning: Cannot convert timestamp', traceback=True)
         return None
     
     if timestamp_date == today:
@@ -981,7 +1024,7 @@ def gui_open(filename):
         # as fallback when xdg-open not available
         return True
     except:
-        log('Cannot open file/folder: "%s"', filename, sender=self, traceback=True)
+        log('Cannot open file/folder: "%s"', filename, traceback=True)
         return False
 
 
@@ -994,12 +1037,19 @@ def open_website(url):
     threading.Thread(target=webbrowser.open, args=(url,)).start()
 
 def sanitize_encoding(filename):
-    """
+    r"""
     Generate a sanitized version of a string (i.e.
     remove invalid characters and encode in the
-    detected native language encoding)
+    detected native language encoding).
+
+    >>> sanitize_encoding('\x80')
+    ''
+    >>> sanitize_encoding(u'unicode')
+    'unicode'
     """
     global encoding
+    if not isinstance(filename, unicode):
+        filename = filename.decode(encoding, 'ignore')
     return filename.encode(encoding, 'ignore')
 
 
@@ -1013,15 +1063,19 @@ def sanitize_filename(filename, max_length=0, use_ascii=False):
     If use_ascii is True, don't encode in the native language,
     but use only characters from the ASCII character set.
     """
-    if max_length > 0 and len(filename) > max_length:
-        log('Limiting file/folder name "%s" to %d characters.', filename, max_length)
-        filename = filename[:max_length]
-
     global encoding
     if use_ascii:
         e = 'ascii'
     else:
         e = encoding
+
+    if not isinstance(filename, unicode):
+        filename = filename.decode(encoding, 'ignore')
+
+    if max_length > 0 and len(filename) > max_length:
+        log('Limiting file/folder name "%s" to %d characters.', filename, max_length)
+        filename = filename[:max_length]
+
     return re.sub('[/|?*<>:+\[\]\"\\\]', '_', filename.strip().encode(e, 'ignore'))
 
 
@@ -1032,8 +1086,75 @@ def find_mount_point(directory):
     it. If not, remove the last part of the path and
     re-check if it's a mount point. If the directory
     resides on your root filesystem, "/" is returned.
+
+    >>> find_mount_point('/')
+    '/'
+
+    >>> find_mount_point(u'/something')
+    Traceback (most recent call last):
+      ...
+    ValueError: Convert unicode objects to str first.
+
+    >>> find_mount_point(None)
+    Traceback (most recent call last):
+      ...
+    ValueError: Directory names should be of type str.
+
+    >>> find_mount_point(42)
+    Traceback (most recent call last):
+      ...
+    ValueError: Directory names should be of type str.
+
+    >>> from minimock import mock
+    >>> mocked_mntpoints = ('/', '/home', '/media/usbdisk', '/media/cdrom')
+    >>> mock('os.path.ismount', returns_func=lambda x: x in mocked_mntpoints)
+    >>>
+    >>> # For mocking os.getcwd(), we simply use a lambda to avoid the
+    >>> # massive output of "Called os.getcwd()" lines in this doctest
+    >>> os.getcwd = lambda: '/home/thp'
+    >>>
+    >>> find_mount_point('.')
+    Called os.path.ismount('/home/thp')
+    Called os.path.ismount('/home')
+    '/home'
+    >>> find_mount_point('relativity')
+    Called os.path.ismount('/home/thp/relativity')
+    Called os.path.ismount('/home/thp')
+    Called os.path.ismount('/home')
+    '/home'
+    >>> find_mount_point('/media/usbdisk/')
+    Called os.path.ismount('/media/usbdisk')
+    '/media/usbdisk'
+    >>> find_mount_point('/home/thp/Desktop')
+    Called os.path.ismount('/home/thp/Desktop')
+    Called os.path.ismount('/home/thp')
+    Called os.path.ismount('/home')
+    '/home'
+    >>> find_mount_point('/media/usbdisk/Podcasts/With Spaces')
+    Called os.path.ismount('/media/usbdisk/Podcasts/With Spaces')
+    Called os.path.ismount('/media/usbdisk/Podcasts')
+    Called os.path.ismount('/media/usbdisk')
+    '/media/usbdisk'
+    >>> find_mount_point('/home/')
+    Called os.path.ismount('/home')
+    '/home'
+    >>> find_mount_point('/media/cdrom/../usbdisk/blubb//')
+    Called os.path.ismount('/media/usbdisk/blubb')
+    Called os.path.ismount('/media/usbdisk')
+    '/media/usbdisk'
     """
-    while os.path.split(directory)[0] != '/':
+    if isinstance(directory, unicode):
+        # We do not accept unicode strings, because they could fail when
+        # trying to be converted to some native encoding, so fail loudly
+        # and leave it up to the callee to encode into the proper encoding.
+        raise ValueError('Convert unicode objects to str first.')
+
+    if not isinstance(directory, str):
+        raise ValueError('Directory names should be of type str.')
+
+    directory = os.path.abspath(directory)
+
+    while directory != '/':
         if os.path.ismount(directory):
             return directory
         else:
